@@ -24,7 +24,7 @@ int main (int argc, char **argv)
 		return 0;
 	}
 
-	watch_dir (fd, "/home/rml", ALL_MASK);
+	watch_dir (fd, argv[1], ALL_MASK);
 	read_and_print_events (fd);
 
 	dev_stats (fd);
